From: Thomas Kellerer <spam_eater@gmx.net>
To: pgsql-performance@lists.postgresql.org
Subject: Re: Should from_collapse be switched off? (queries 10 times faster)
Date: Fri, 23 Mar 2018 12:39:07 +0100
Message-ID: <71c6894e-f924-4aca-dad7-a22d19bb5b75@gmx.net> (raw)
In-Reply-To: <20180323100308.GA1188@gate.oper.dinoex.org>
References: <20180323100308.GA1188@gate.oper.dinoex.org>
Peter schrieb am 23.03.2018 um 11:03:
> My queries get up to 10 times faster when I disable from_collapse
> (setting from_collapse_limit=1).
>
> After this finding, The pramatic solution is easy: it needs to be
> switched off.
You should post some example queries together with the slow and fast plans.
Ideally generated using "explain(analyze, buffers)" instead of a simple "explain" to see details on the execution
Thomas
Reply instructions:
You may reply publicly to this message via plain-text email
using any one of the following methods:
* Reply to all the recipients using the --to and --cc options:
reply via email
To: pgsql-performance@postgresql.org
Cc: spam_eater@gmx.net, pgsql-performance@lists.postgresql.org
Subject: Re: Should from_collapse be switched off? (queries 10 times faster)
In-Reply-To: <71c6894e-f924-4aca-dad7-a22d19bb5b75@gmx.net>
* Save the following mbox file, import it into your mail client,
and reply-to-all from there: mbox
This inbox is served by DDX for PostgreSQL; see mirroring instructions
for how to clone and mirror all data and code used for this inbox